Struct ZwlrForeignToplevelManagerV1
pub struct ZwlrForeignToplevelManagerV1 { /* private fields */ }wayland and Linux only.Expand description
list and control opened apps
The purpose of this protocol is to enable the creation of taskbars and docks by providing them with a list of opened applications and letting them request certain actions on them, like maximizing, etc.
After a client binds the zwlr_foreign_toplevel_manager_v1, each opened toplevel window will be sent via the toplevel event
See also the Request enum for this interface.
Implementations
impl ZwlrForeignToplevelManagerV1
impl ZwlrForeignToplevelManagerV1
pub fn toplevel(&self, toplevel: &ZwlrForeignToplevelHandleV1)
pub fn toplevel(&self, toplevel: &ZwlrForeignToplevelHandleV1)
a toplevel has been created
This event is emitted whenever a new toplevel window is created. It is emitted for all toplevels, regardless of the app that has created them.
All initial details of the toplevel(title, app_id, states, etc.) will be sent immediately after this event via the corresponding events in zwlr_foreign_toplevel_handle_v1.
pub fn finished(&self)
pub fn finished(&self)
the compositor has finished with the toplevel manager
This event indicates that the compositor is done sending events to the zwlr_foreign_toplevel_manager_v1. The server will destroy the object immediately after sending this request, so it will become invalid and the client should free any resources associated with it.